import meter.*;
import processing.serial.*;
Serial port;

Meter m;

void setup() {
  size(550, 400);
  background(0,0,0);
  port = new Serial(this, "COM11", 9600); //name of the port would be different for linux
  
  // Lets add a default meter to empty window
  // TEMPERATURE METER
  m = new Meter(this, 30, 115);  // here 25, 10 are x and y coordinates of meter's upper left corner
  
  m.setTitleFontSize(20);
  m.setTitleFontName("Arial bold");
  m.setTitle("Temperature (*C)");
  
  // Change meter scale values
  String[] scaleLabels = {"0", "15", "30", "45", "60", "75", "90", "105", "120"};
  m.setScaleLabels(scaleLabels);
  m.setScaleFontSize(18);
  m.setScaleFontName("Times new roman bold");
  m.setScaleFontColor(color(200, 30, 70));
  
  // We can also display the value of meter
  m.setDisplayDigitalMeterValue(true);
  
  // Lets do some more modifications so our meter looks nice
  m.setArcColor(color(141, 113, 178));
  m.setArcThickness(15);
  m.setMaxScaleValue(120);
  m.setNeedleThickness(3);
}

void draw(){
  
  textSize(30);
  fill(255, 0, 0); // Font color , (r,g,b)
  text("Temperature Meter ", 150, 40); // ("text", x, y)
  
  if (port.available() > 0){
    String val = port.readString(); // read incoming string on serial port
    float temp = float(val); // first value is Temperature
    
    m.updateMeter(int(temp)); // int is used due to updateMeter accepts only int values
    println(temp);
  }
}
